==> gswidgetkit-0.0.3.tar.gz: gswidgetkit-0.0.3/README.md <==
#   G S   W i d g e t   K i t 
 
 
 
 V a r i o u s   c u s t o m   w i d g e t s   f o r   w x p y t h o n ,   c r e a t e d   t o   b e   e v e n t u a l l y   u s e d   i n   [ G i m e l   S t u d i o ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o ) . 
 
 
 
 H i g h l y   i n s p i r e d   b y   t h e   l o o k   a n d   f u n c t i o n a l i t y   o f   B l e n d e r   a n d   S k e t c h   w i d g e t s . 
 
 
 
 ! [ " G S w i d g e t k i t   d e m o " ] ( h t t p s : / / i . i b b . c o / x g C W L q J / S c r e e n s h o t - 2 0 2 1 - 0 5 - 1 3 - 0 9 0 3 0 6 . p n g   " G S w i d g e t k i t   d e m o " ) 
 
 
 
 
 
 #   C o n t e n t s 
 
 
 
 -   [ x ]   B u t t o n s   ( W i t h   t e x t   +   i c o n   o r   j u s t   i c o n ) 
 
 -   [ x ]   N u m b e r   F i e l d   ( s i m i l a r   t o   B l e n d e r ' s   N u m b e r   F i e l d   c o n t r o l ) 
 
 -   [ x ]   C o l o r   P i c k e r 
 
 -   [ x ]   T e x t c t r l 
 
 -   [   ]   D r o p d o w n 
 
 -   [   ]   I m a g e   P i c k e r 
 
 -   [   ]   C h e c k b o x 
 
 -   [   ]   R a d i o   B u t t o n s 
 
 
 
 
 
 #   G e t   s t a r t e d 
 
 
 
 S i m p l y   ` ` ` p i p   i n s t a l l   g s w i d g e t k i t ` ` `   a n d   r u n   t h e   ` ` ` d e m o . p y ` ` `     f i l e   f o r   a   d e m o   o f   t h e   w i d g e t s . 
 
 
 
 
 
 #   C o n t r i b u t i n g 
 
 
 
 A l l   c o n t r i b u t i o n s   a r e   w e l c o m e !   S e e   [ C O N T R I B U T I N G . m d ] ( C O N T R I B U T I N G . m d )   f o r   d e t a i l s .   F e e l   f r e e   t o   o p e n   a   P R   o r   a s k   q u e s t i o n s . 
 
 

==> gswidgetkit-0.1.1.tar.gz: gswidgetkit-0.1.1/README.md <==
#   G S   W i d g e t   K i t 
 
 
 
 V a r i o u s   c u s t o m   w i d g e t s   f o r   w x p y t h o n ,   c r e a t e d   t o   b e   u s e d   i n   [ G i m e l   S t u d i o ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o ) . 
 
 
 
 H i g h l y   i n s p i r e d   b y   t h e   l o o k   a n d   f u n c t i o n a l i t y   o f   B l e n d e r   a n d   S k e t c h   w i d g e t s .   C u r r e n t l y ,   i t   u s e s   s o m e   h a r d c o d e d   s t y l e s   f o r   G i m e l   S t u d i o . 
 
 
 
 
 
 #   C o n t e n t s 
 
 
 
 -   [ x ]   B u t t o n s   ( W i t h   t e x t   +   i c o n   o r   j u s t   i c o n ) 
 
 -   [ x ]   N u m b e r   F i e l d   ( s i m i l a r   t o   B l e n d e r ' s   N u m b e r   F i e l d   c o n t r o l ) 
 
 -   [ x ]   C o l o r   P i c k e r 
 
 -   [ x ]   T e x t c t r l 
 
 -   [ x ]   C h e c k b o x 
 
 -   [   ]   D r o p d o w n 
 
 -   [   ]   I m a g e   P i c k e r 
 
 -   [   ]   R a d i o   B u t t o n s 
 
 
 
 
 
 #   G e t   s t a r t e d 
 
 
 
 S i m p l y   ` ` ` p i p   i n s t a l l   g s w i d g e t k i t ` ` `   a n d   r u n   t h e   ` ` ` d e m o . p y ` ` `     f i l e   f o r   a   d e m o   o f   t h e   w i d g e t s . 
 
 
 
 
 
 #   C o n t r i b u t i n g 
 
 
 
 A l l   c o n t r i b u t i o n s   a r e   w e l c o m e !   S e e   [ C O N T R I B U T I N G . m d ] ( C O N T R I B U T I N G . m d )   f o r   d e t a i l s .   F e e l   f r e e   t o   o p e n   a   P R   o r   a s k   q u e s t i o n s . 
 
 
